@@ -14,6 +14,10 @@ class TestRedisCache(object):
         self.conn = Mock()
         self.cache = RedisCache(self.conn)
 
-    def test_set_expiration(self):
+    def test_set_expiration_datetime(self):
         self.cache.set("foo", "bar", expires=datetime(2014, 2, 2))
         assert self.conn.setex.called
+
+    def test_set_expiration_int(self):
+        self.cache.set("foo", "bar", expires=600)
+        assert self.conn.setex.called
